@@ -41,9 +41,7 @@ def updatebc(bctype):
         time.sleep(5)
         rec10d.rec10db.update_by_bctype_epg_ch(bctype)
     except Exception, inst:
-        recdblist.printutf8("error occurs in updatebc(epgdb)")
-        recdblist.printutf8(str(type(inst)))
-        recdblist.printutf8(str(inst))
+        recdblist.Commonlogex("Error","updatebc(epgdb.py)", str(type(inst)), str(inst))
         xml2db_dom.xml2db_dom(tmppath + bctype + "epgdata.bak.xml", bctype)
         rec10d.rec10db.update_status_by_bctype_epg_ch(bctype, "2")
 def updatebc_bak(bctype):
