@@ -4,6 +4,7 @@
 # Copyright (C) 2009-2010 Yukikaze
 
 import os
+import os.path
 import re
 import time
 import os
@@ -11,34 +12,45 @@ import datetime
 import n_gram
 import recdblist
 import zenhan
+import auto_move
 
-def detName(title,path):
-    tt=detNameType(title, path)
-    if tt['type']=="C"or tt['type']=="D":
-        tt['num']=detNum(tt['title'],tt['folder'])
-def detNum(title,movepath):
+def detSeriesNum(execpath):
+    files=os.listdir(execpath)
+    ss={}
+    for file in files:
+        ftitle=os.path.splitext(file)
+        fname=ftitle[0]
+        fname=zenhan.toHankaku(unicode(fname,"utf-8"))
+        nt=detNameType(fname, execpath)
+        st=nt['title']
+        if not ss.has_key(st):
+            ss[st]={}
+        ss[st][nt['num']]=ftitle
+        print ss
+    return ss
+def detDeltaNum(title,movepath):
     """
-        #
+        #番組の話数を推測する。
     """
     files=os.listdir(movepath)
     ff=[]
     maxnum=0
     for file in files:
-        recdblist.printutf8(file)
+        recdblist.printutf8(unicode(file,'utf-8'))
         file=os.path.join(movepath,file)
         if os.path.isfile(file):
             name=os.path.splitext(os.path.split(file)[1])
             name=name[0]
-            name=zenhan.toHankaku(unicode(name))
+            name=zenhan.toHankaku(unicode(name,'utf-8'))
             p1=detNameType(name,movepath)
-            recdblist.printutf8(p1['title']+" "+str(p1['num']))
+            #recdblist.printutf8(p1['title']+" "+str(p1['num']))
             time1=time.localtime(os.path.getmtime(file))
             time1=datetime.datetime.fromtimestamp(os.path.getmtime(file))
             if p1['num']!=-1:
                 ff.append([p1['num'],p1['title'],time1])
                 if maxnum<p1['num']+1:
                     maxnum=p1['num']+1
-    detMultiDeltaDays(ff)
+    return detMultiDeltaDays(ff)
 def detMultiDeltaDays(num_with_title_with_dates):
     maxnum=0
     for ft in num_with_title_with_dates:
@@ -92,7 +104,7 @@ def detSingleDeltaDay(num1,date1,num2,date2):
         dm=dm+d
     if dp%d*2>d:
         dp=dp+d
-    recdblist.printutf8(str(d)+":"+str(dn))
+    #recdblist.printutf8(str(d)+":"+str(dn))
     if dp!=dn:
         ret.append([dn/d,60])
         ret.append([dp/d,40])
@@ -111,7 +123,14 @@ def detNameType(title,path):
     type Aj ---title第<number>話
     path --search reflexively
     """
+    new=0
+    if re.search(u"[新]",title) or re.search(u" 新",title):
+        title=title.replace(u"[新]","")
+        title=title.replace(u" 新","")
+        new=1
     recdblist.printutf8(title)
+    title=auto_move.getTitle(title)##titleから日時を除く
+    title=title.replace(u"無料≫","")
     #rA=re.compile(".+(?P<title>)#\d(?P<num>)\s[0,10]\z")
     rA=re.compile("(.+)#(\d*)\s*\Z")
     tA=rA.match(title)
@@ -121,30 +140,30 @@ def detNameType(title,path):
     tAj=rAj.match(title)
     ret={'title':"",'type':"",'num':0,'subtitle':"",'folder':""}
     if tA:
-        recdblist.printutf8("typeA")
-        recdblist.printutf8("title="+tA.group(1))
-        recdblist.printutf8("num="+tA.group(2))
+        #recdblist.printutf8("typeA")
+        #recdblist.printutf8("title="+tA.group(1))
+        #recdblist.printutf8("num="+tA.group(2))
         ret['type']="A"
-        ret['title']=tA.group(1)
+        ret['title']=tA.group(1).replace(" ","")
         ret['num']=int(tA.group(2))
-        ret['folder']=searchFolder(tA.group(1),path)
+        ret['folder']=searchFolder(tA.group(1),unicode(path,'utf-8'))
     if tAj:
-        recdblist.printutf8("typeA")
-        recdblist.printutf8("title="+tAj.group(1))
-        recdblist.printutf8("num="+tAj.group(2))
+        #recdblist.printutf8("typeA")
+        #recdblist.printutf8("title="+tAj.group(1))
+        #recdblist.printutf8("num="+tAj.group(2))
         ret['type']="Aj"
-        ret['title']=tAj.group(1)
+        ret['title']=tAj.group(1).replace(" ","")
         ret['num']=int(tAj.group(2))
-        ret['folder']=searchFolder(tAj.group(1),path)
+        ret['folder']=searchFolder(tAj.group(1),unicode(path,'utf-8'))
     elif tB:
-        recdblist.printutf8("typeB")
-        recdblist.printutf8("title="+tB.group(1))
-        recdblist.printutf8("num="+tB.group(2))
-        recdblist.printutf8("subtitle="+tB.group(3))
+        #recdblist.printutf8("typeB")
+        #recdblist.printutf8("title="+tB.group(1))
+        #recdblist.printutf8("num="+tB.group(2))
+        #recdblist.printutf8("subtitle="+tB.group(3))
         ret['type']="B"
-        ret['title']=tB.group(1)
+        ret['title']=tB.group(1).replace(" ","")
         ret['num']=int(tB.group(2))
-        ret['folder']=searchFolder(tB.group(1),path)
+        ret['folder']=searchFolder(tB.group(1),unicode(path,'utf-8'))
         ret['subtitle']=tB.group(3)
     else:#type C or type D
         #fold=searchFolder(title, path)
@@ -153,8 +172,8 @@ def detNameType(title,path):
         rt=["",0,""]
         for t in ts:
             tt=tt+" "+t
-            ft1=searchFolder(tt,path)
-            recdblist.printutf8(tt)
+            ft1=searchFolder(tt,unicode(path,'utf-8'))
+            #recdblist.printutf8(tt)
             #print ft1
             if ft1!="":
                 #recdblist.printutf8(rt)
@@ -166,7 +185,7 @@ def detNameType(title,path):
                     #recdblist.printutf8(rt)
         #recdblist.printutf8("title="+rt[0][1:]+"/")
         #recdblist.printutf8("subtitle = "+title.replace(rt[0][1:],"")[1:])
-        ret['title']=rt[0][1:]
+        ret['title']=rt[0][1:].replace(" ","")
         ret['num']=-1
         ret['folder']=rt[2]
         ret['subtitle']=title.replace(rt[0][1:],"")[1:]
@@ -174,6 +193,8 @@ def detNameType(title,path):
             ret['type']="D"
         else:
             ret['type']="C"
+    if new==1:
+        ret['num']=1
     return ret
 def searchFolder(title,path,threshold=500):
     """
@@ -201,7 +222,9 @@ def searchFolder(title,path,threshold=500):
         else:
             cmpp=os.path.basename(dirp)
             appp=os.path.dirname(dirp)
-        p=n_gram.trigram(title,cmpp)
+        ntitle=auto_move.getTitle(title)
+        ncmpp=auto_move.getTitle(cmpp)
+        p=n_gram.trigram(ntitle,ncmpp)
         if p>0:
             ngram.append((p,appp))
     ngram=list(set(ngram))
