@@ -75,7 +75,7 @@ def getpath(cmd):
 def move():
     useB=0
     path = str(os.path.dirname(os.path.abspath(__file__)))
-    printutf8(u"rec10 ver 0.9.4 installer.")
+    printutf8(u"rec10 ver "+recdblist.version_str+" installer.")
     printutf8(u"rec10のインストールを開始します。")
     maxn=14
     configwriter.setpath(u"wine", getpath(u"wine"))
@@ -84,7 +84,6 @@ def move():
     configwriter.setpath(u"mp4box", getpath(u"MP4Box"))
     configwriter.setpath(u"mencoder", getpath(u"mencoder"))
     configwriter.setpath(u"ffmpeg", getpath(u"ffmpeg"))
-    #configwriter.setpath(u"xvfb-run", getpath(u"xvfb-run"))
     configwriter.setpath(u"mkvmerge", getpath(u"mkvmerge"))
     configwriter.setpath(u"b25", getpath(u"b25"))
     printutf8(u"必須環境の設定が完了しました")
@@ -97,7 +96,7 @@ def move():
             useB=0
         else:
             useB=1
-            printutf8(u"設定ファイルのインポーを行います。")
+            printutf8(u"設定ファイルのインポートを行います。")
     printutf8(u"rec10の録画ファイルが置かれる場所を入力してください(1/"+str(maxn)+")")
     printutf8(u"100GB程度は確保されている必要があります")
     recpath=getConf(useB,"/etc/rec10.conf","path","recpath","path : ")
@@ -287,5 +286,9 @@ def update_db(version):
         rec10d.rec10db.update_db_to93()
     elif version==93:
         rec10d.rec10db.update_db_93to94()
+    elif version==94:
+        rec10d.rec10db.update_db_94to95()
+    elif version==95:
+        rec10d.rec10db.update_db_95to96()
 if __name__ == "__main__":
     move()
