@@ -9,10 +9,11 @@ import time
 import tv2avi
 import tv2mkv
 import checker
+import guess
 import auto_process
 import install
 #import datetime
-#import rec10d
+import rec10d
 #import os
 #import time
 #import n_gram
@@ -34,13 +35,10 @@ import install
 #import zenhan
 #import auto_process
 import datetime
-__author__ = "yukikaze"
+import tv2mp4
 path = str(os.path.dirname(os.path.abspath(__file__))) + "/"
 recpath = "/home/ftpusr/ftp-tmp/Recording/"
 ftpusr = "/home/ftpusr/ftp-tmp"
-recordedpath = "/home/ftpusr/ftp5/Series-Finish/"
-
+recordedpath = u"/home/ftpusr/ftp-video"
 if __name__ == "__main__":
-    bt=datetime.datetime.now()
-    install.update_db_all()
-    print dt.seconds
\ No newline at end of file
+    ""
\ No newline at end of file
