@@ -512,16 +512,7 @@ def type_decode_que(typetxt,chtxt,title,bt,et,opt):
                 recdb.del_reckey(typetxting, title, chtxt, btime)
                 recdb.rec_reckey(typetxtmiss, title, chtxt, btime, etime, opt)
             else:
-                cstch=-1
-                try:
-                    cstch=int(chdb.chtxtsearch(chtxt)['csch'])
-                except:
-                    cstch=-1
-                if cstch>-1:
-                    ch=checker.checkB25Decode(recpath + "/" + title + ".ts.b25", recpath + "/" + title + ".ts",cstch)
-                #print ch
-                if ch == 1:
-                    os.remove(recpath + "/" + title + ".ts.b25")
+                auto_process.deltmpfile(recpath, title, ".ts")
             bt = datetime.datetime.strptime(btime, "%Y-%m-%d %H:%M:%S")
             et = datetime.datetime.strptime(etime, "%Y-%m-%d %H:%M:%S")
             dt = et-bt
@@ -535,6 +526,9 @@ def type_decode_que(typetxt,chtxt,title,bt,et,opt):
             else:
                 try:
                     shutil.copy(os.path.join(recpath,title+".ts"), os.path.join(movepath,title+".ts"))
+                    time.sleep(5)
+                    if os.path.getsize(os.path.join(recpath,title+".ts"))==os.path.getsize(os.path.join(movepath,title+".ts")):
+                        os.remove(os.path.join(recpath,title+".ts"))
                 except Exception, inst:
                     errtxt1="move ts error.\n"
                     errtxt2=str(type(inst))+"\n"
