@@ -26,8 +26,7 @@ def write_time(pout, ch ,times):
     """
     指定された時間分tsを取得してepgの入ったxmlとして書き出す
     """
-    recdblist.printutf8(u"Ts-EPG XML書き出し処理開始")
-    recdblist.printutf8(u"CH:"+ch)
+    recdblist.Commonlogex(u"通常","write_time(ts2epg.py)",u"Ts-EPG XML書き出し処理開始" ,u"CH:"+ch)
     timet = times
     if re.search(u'CS', ch):
         mode = "/CS"
@@ -42,6 +41,7 @@ def write_time(pout, ch ,times):
     tv2ts.tv2tsmix(pout + ".ts", ch, timet)
     exe = "export LANG=ja_JP.UTF-8 && nice -n 15 " + epgdump + " " + mode + " " + pout + ".ts " + pout
     recdblist.printutf8(exe)
+    recdblist.Commonlogex(u"通常", "write_time(ts2epg.py)", exe,"")
     os.system(exe)
     time.sleep(10)
 
