@@ -13,7 +13,7 @@ our $svg="";
 our $dbh;
 my $cgi=CGI::Minimal->new;
 my $nHTML="";
-my $VERSION="0.9.6a";
+my $VERSION="0.9.7a";
 
 my $cfg = new Config::Simple;
 if ( -e '/etc/rec10.conf' ) {
@@ -139,16 +139,16 @@ if ($cgi->param('mode') eq "graph"){
 	$nHTML .= qq {<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"\n"http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">\n};
 	$nHTML .= qq {<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="ja" lang="ja">\n};
 	$nHTML .= qq {<head>\n};
-	$nHTML .= qq {<title>Rec10WEB G2 番組表 ver beta r1015};
+	$nHTML .= qq {<title>Rec10WEB G2 番組表 ver0.9.5(beta 0425)};
 	$nHTML .= qq {</title>\n};
 	$nHTML .= qq {</head>\n};
 	$nHTML .= qq {<body bgcolor="#F4FBF1">\n};
 	$nHTML .= qq {<form id="form1" action="rec10webg2.pl">\n};
-	$nHTML .= qq {<p>Rec10WEB G2 beta 0317</p>\n};
-	$nHTML .= qq {<p>Rec10 番組表  | 説明        <span style="color:#3EB370;">おすすめ</span>    <span style="color:#40A3FF;">地引</span>};
+	$nHTML .= qq {<p style="width:100%;top:0%;height:1%;position:absolute;">Rec10WEB G2 beta 0425</p>\n};
+	$nHTML .= qq {<p style="width:100%;top:4%;height:3%;position:absolute;">Rec10 番組表  | 説明        <span style="color:#3EB370;">おすすめ</span>    <span style="color:#40A3FF;">地引</span>};
 	$nHTML .= qq {    <span style="color:#F57A6E;">録画済み</span>    <span style="color:#93668A;">録画満杯</span>};
 	$nHTML .= qq {    <span style="color:#C34F47;">録画オーバー</span>    <span style="color:#FFA8DC;">時間変更あり</span></p>\n};
-	$nHTML .= qq {<p style="width:100%;height:10%;buttom:2%;position:relative;">};
+	$nHTML .= qq {<p style="width:100%;top:9%;height:3%;position:absolute;">};
 	$nHTML .= qq {<select size="1" name="ch1" style="left:3%;width:30%;height:100%;position:relative;" onchange="submit(this.form)">\n};
 	$nHTML .= $chtxtlist1;
 	$nHTML .= qq {</select>\n};
@@ -160,7 +160,7 @@ if ($cgi->param('mode') eq "graph"){
 	$nHTML .= qq {</select>\n};
 	$nHTML .= qq {<input type="submit" name="submit" value="表示" style="left:3%;width:3%;position:relative;"/>\n};
 	$nHTML .= qq {</p>\n};
-	$nHTML .= qq {<div style="width:100%;height:82%;bottom:3%;position:fixed;">\n};
+	$nHTML .= qq {<div style="width:100%;bottom:4%;position:absolute;height:80%">\n};
 	$nHTML .= qq {<object type="image/svg+xml" data="rec10webg2.pl?mode=timegraph&amp;btime=$btxt&amp;etime=$etxt" style="width:3%;height:100%;">\n};
 	$nHTML .= qq {SVG Timeline\n};
 	$nHTML .= qq {</object>\n};
@@ -177,7 +177,7 @@ if ($cgi->param('mode') eq "graph"){
 	$nHTML .= qq {SVG Timeline\n};
 	$nHTML .= qq {</object>\n};
 	$nHTML .= qq {</div>\n};
-	$nHTML .= qq {<p style="bottom:1%;position:fixed;">\n};
+	$nHTML .= qq {<p style="bottom:1%;height:0.6%;position:absolute;">\n};
 	$nHTML .= qq {<a href="$blink" style="left:1%;position:fixed;">前へ</a>\n};
 	$nHTML .= qq {<a href="$b3link" style="left:6%;position:fixed;">-3日</a>\n};
 	$nHTML .= qq {<a href="$sixhour" style="left:40%;position:fixed;">6時間</a>\n};
